@@ -1,7 +1,7 @@
 package Dist::Inkt::Role::ProcessDOAP;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010';
+our $VERSION   = '0.011';
 
 use Moose::Role;
 use List::MoreUtils 'uniq';
@@ -55,40 +55,41 @@ sub cpanmeta_license_code
 	for (@{ $self->doap_project->license })
 	{
 		my $license_code = {
-			'http://www.gnu.org/licenses/agpl-3.0.txt'              => 'open_source',
+			'http://www.gnu.org/licenses/agpl-3.0.txt'              => 'agpl_3',
 			'http://www.apache.org/licenses/LICENSE-1.1'            => 'apache_1_1',
-			'http://www.apache.org/licenses/LICENSE-2.0'            => 'apache',
-			'http://www.apache.org/licenses/LICENSE-2.0.txt'        => 'apache',
-			'http://www.perlfoundation.org/artistic_license_1_0'    => 'artistic',
-			'http://opensource.org/licenses/artistic-license.php'   => 'artistic',
+			'http://www.apache.org/licenses/LICENSE-2.0'            => 'apache_2_0',
+			'http://www.apache.org/licenses/LICENSE-2.0.txt'        => 'apache_2_0',
+			'http://www.perlfoundation.org/artistic_license_1_0'    => 'artistic_1',
+			'http://opensource.org/licenses/artistic-license.php'   => 'artistic_1',
 			'http://www.perlfoundation.org/artistic_license_2_0'    => 'artistic_2',
 			'http://opensource.org/licenses/artistic-license-2.0.php'  => 'artistic_2',
 			'http://www.opensource.org/licenses/bsd-license.php'    => 'bsd',
 			'http://creativecommons.org/publicdomain/zero/1.0/'     => 'unrestricted',
-			'http://www.freebsd.org/copyright/freebsd-license.html' => 'open_source',
-			'http://www.gnu.org/copyleft/fdl.html'                  => 'open_source',
-			'http://www.opensource.org/licenses/gpl-license.php'    => 'gpl',
-			'http://www.gnu.org/licenses/old-licenses/gpl-1.0.txt'  => 'gpl',
-			'http://www.opensource.org/licenses/gpl-2.0.php'        => 'gpl2',
-			'http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt'  => 'gpl2',
-			'http://www.opensource.org/licenses/gpl-3.0.html'       => 'gpl3',
-			'http://www.gnu.org/licenses/gpl-3.0.txt'               => 'gpl3',
-			'http://www.opensource.org/licenses/lgpl-license.php'   => 'lgpl',
-			'http://www.opensource.org/licenses/lgpl-2.1.php'       => 'lgpl2',
-			'http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt' => 'lgpl2',
-			'http://www.opensource.org/licenses/lgpl-3.0.html'      => 'lgpl3',
-			'http://www.gnu.org/licenses/lgpl-3.0.txt'              => 'lgpl3',
+			'http://www.freebsd.org/copyright/freebsd-license.html' => 'freebsd',
+			'http://www.gnu.org/licenses/old-licenses/fdl-1.2.html' => 'gfdl_1_2',
+			'http://www.gnu.org/copyleft/fdl.html'                  => 'gfdl_1_3',
+			'http://www.opensource.org/licenses/gpl-license.php'    => 'gpl_1',
+			'http://www.gnu.org/licenses/old-licenses/gpl-1.0.txt'  => 'gpl_1',
+			'http://www.opensource.org/licenses/gpl-2.0.php'        => 'gpl_2',
+			'http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt'  => 'gpl_2',
+			'http://www.opensource.org/licenses/gpl-3.0.html'       => 'gpl_3',
+			'http://www.gnu.org/licenses/gpl-3.0.txt'               => 'gpl_3',
+			'http://www.opensource.org/licenses/lgpl-license.php'   => 'open_source',
+			'http://www.opensource.org/licenses/lgpl-2.1.php'       => 'lgpl_2_1',
+			'http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt' => 'lgpl_2_1',
+			'http://www.opensource.org/licenses/lgpl-3.0.html'      => 'lgpl_3_0',
+			'http://www.gnu.org/licenses/lgpl-3.0.txt'              => 'lgpl_3_0',
 			'http://www.opensource.org/licenses/mit-license.php'    => 'mit',
-			'http://www.mozilla.org/MPL/MPL-1.0.txt'                => 'mozilla',
-			'http://www.mozilla.org/MPL/MPL-1.1.txt'                => 'mozilla',
-			'http://opensource.org/licenses/mozilla1.1.php'         => 'mozilla',
-			'http://www.openssl.org/source/license.html'            => 'open_source',
-			'http://dev.perl.org/licenses/'                         => 'perl',
+			'http://www.mozilla.org/MPL/MPL-1.0.txt'                => 'mozilla_1_0',
+			'http://www.mozilla.org/MPL/MPL-1.1.txt'                => 'mozilla_1_1',
+			'http://opensource.org/licenses/mozilla1.1.php'         => 'mozilla_1_1',
+			'http://www.openssl.org/source/license.html'            => 'openssl',
+			'http://dev.perl.org/licenses/'                         => 'perl_5',
 			'http://www.opensource.org/licenses/postgresql'         => 'open_source',
-			'http://trolltech.com/products/qt/licenses/licensing/qpl'  => 'open_source',
-			'http://h71000.www7.hp.com/doc/83final/BA554_90007/apcs02.html'  => 'unrestricted',
-			'http://www.openoffice.org/licenses/sissl_license.html' => 'open_source',
-			'http://www.zlib.net/zlib_license.html'                 => 'open_source',
+			'http://trolltech.com/products/qt/licenses/licensing/qpl'  => 'qpl_1_0',
+			'http://h71000.www7.hp.com/doc/83final/BA554_90007/apcs02.html'  => 'ssleay',
+			'http://www.openoffice.org/licenses/sissl_license.html' => 'sun',
+			'http://www.zlib.net/zlib_license.html'                 => 'zlib',
 			}->{ $_->uri };
 
 		push @r, $license_code if $license_code;
